==> motd1.0.4.tar.gz: motd/settings.tcl <==
# Settings file for motd 1.0 by Corbe. Please edit this file only.

# Enable the G user flag? This will allow users on the bot to stop/start
# recieving the MOTD of the channel. Useful for people who get annoyed
# easily. [0/1] (0 = off and 1 = on)
set wantgflag 1

# Enable CTCP Cloaking? This will hide the fact that you have MOTD loaded
# on an eggdrop bot in CTCP Version.  Useful to hide the bot from nosey
# IRCops who go bot hunting ;-) (however I think that displaying a whole
# file's worth of text to the person /join'ing a channel pretty much blows
# it's cover anyways.) [0/1] (0 = off and 1 = on)
set ctcpcloak 1

# Set the follwing variable to the word of your bot (E.G. what you /msg it
# to introduce yourself).
set myword "hello"

# If you have wantgflag set uncomment this. It's here cause you might
# already have another custom flag bound to the default setting. Please
# only change this if you know what your doing.
set flag1 g

# Set this to the location of your motd file. 
set motdpath "/home/bots/bots/MasterP/test.motd"

# Set this to 1 if you want CPU Awarness(tm).
# 
# Pros: Cut the script's memory and CPU usage basically in half. Good if
#       your already hogigng your machines CPU power for other bots with
#       tons of scripts loaded.
# Cons: If you decide you want to change any of the settings in
#       settings.tcl, you'll have to do a .rehash before the changes will
#       take affect. 
set cpuawarness 0

# End configuration section. Don't change anthing below this line.

if {$wantgflag == "1"} {
  bind msg - hello *hello
  set learnusers 1
}
  
if {![file exists $motdpath]} {
  die "motd: Error: $motdpath does not exist!"
}

==> motd1.1+1.3.tar.gz: motd/settings.tcl <==
# Settings file for motd 1.1 by Corbe. Please edit this file only.

# Enable the G user flag? This will allow users on the bot to stop/start
# recieving the MOTD of the channel. Useful for people who get annoyed
# easily. [0/1] (0 = off and 1 = on)
set wantgflag 1

# Enable CTCP Cloaking? This will hide the fact that you have MOTD loaded
# on an eggdrop bot in CTCP Version.  Useful to hide the bot from nosey
# IRCops who go bot hunting ;-) (however I think that displaying a whole
# file's worth of text to the person /join'ing a channel pretty much blows
# it's cover anyways.) [0/1] (0 = off and 1 = on)
set ctcpcloak 0

# Set the follwing variable to the word of your bot (E.G. what you /msg it
# to introduce yourself).
set myword "hello"

# If you have wantgflag set uncomment this. It's here cause you might
# already have another custom flag bound to the default setting. Please
# only change this if you know what your doing.
set flag1 G

# Set this to the location of your motd files. ***NEEDS TRAILING /
set motdpath "/home/ircadmin/eggdrop/"

# Set this to each channel you want your bot to set in. Please see
# README.multichan for info.
set channels "#Admin #Twilight_Zone #Test2"

# Set this to 1 if you want.
#
# It's not reccommended you change this as setting it to 1 might cause
# problems.
set cpuawarness 0

# End configuration section. Don't change anthing below this line.

if {$wantgflag == "1"} {
  bind msg - hello *hello
  set learnusers 1
}
  
if {![file exists $motdpath]} {
  die "motd: Error: $motdpath does not exist!"
}
